"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const path_1 = require("path");
const fs_1 = require("fs");
const glob_1 = __importDefault(require("glob"));
const resolver_js_1 = require("vite/dist/node/resolver.js");
const modulesDir = path_1.join(process.cwd(), '/node_modules/');
const globbyTransfrom = function (config) {
    const resolver = resolver_js_1.createResolver(config.root || process.cwd(), config.resolvers || [], config.alias || {});
    return {
        test(ctx) {
            const filePath = ctx.path.replace('\u0000', ''); // why some path startsWith '\u0000'?
            return (!filePath.startsWith(modulesDir) &&
                /\.(vue|js|jsx|ts|tsx)$/.test(filePath) &&
                fs_1.lstatSync(ctx.path).isFile());
        },
        transform(ctx) {
            ctx.code = ctx.code.replace(/import\s+(\w+)\s+from\s+(['"])([^'"]+\*+[^'"]+)\2/g, (_, g1, g2, g3) => {
                const filePath = ctx.path.replace('\u0000', ''); // why some path startsWith '\u0000'?
                const resolvedFilePath = g3.startsWith('.')
                    ? resolver.resolveRelativeRequest(filePath, g3)
                    : { pathname: resolver.requestToFile(g3) };
                const files = glob_1.default.sync(resolvedFilePath.pathname, { dot: true });
                let groups = [];
                let replaceFiles = files.map((f, i) => {
                    groups.push(g1 + i);
                    return `import ${g1 + i} from ${g2}${resolver.fileToRequest(f)}${g2}`;
                });
                return (replaceFiles.join('\r\n') +
                    `\r\nconst ${g1} = { ${groups.join(', ')} }\r\n`);
            });
            // console.log(ctx.code)
            return ctx;
        }
    };
};
module.exports = globbyTransfrom;
//# sourceMappingURL=index.js.map